package com.ruoyi.system.controller;

import java.util.List;


import com.ruoyi.system.domain.ActSupplies;
import com.ruoyi.system.domain.ActSuppliesRole;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ActSuppliesRoleDetail;
import com.ruoyi.system.service.IActSuppliesRoleDetailService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 规则详情Controller
 *
 * @author dongjg
 * @date 2023-07-13
 */
@RestController
@RequestMapping("/system/suppliesroledetail")
public class ActSuppliesRoleDetailController extends BaseController
{
    @Autowired
    private IActSuppliesRoleDetailService actSuppliesRoleDetailService;


    /**
     * 查询上级分类
     * */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:savesid')")
    @GetMapping("/savesid")
    @ResponseBody
    public TableDataInfo saveSid(){

        List<ActSuppliesRole> options = actSuppliesRoleDetailService.saveSid();

        return getDataTable(options);

    }

//    /**
//     * 查询运算方法
//     * */
//    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:saveOperation')")
//    @GetMapping("/saveOperation")
//    @ResponseBody
//    public TableDataInfo saveOperation(){
//
//        List<ActOperation> options = actSuppliesRoleDetailService.saveOperation();
//
//        return getDataTable(options);
//
//    }

    /**
     * 查询规则详情列表
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:list')")
    @GetMapping("/list")
    public TableDataInfo list(ActSuppliesRoleDetail actSuppliesRoleDetail)
    {
        startPage();
        List<ActSuppliesRoleDetail> list = actSuppliesRoleDetailService.selectActSuppliesRoleDetailList(actSuppliesRoleDetail);
        return getDataTable(list);
    }

    /**
     * 导出规则详情列表
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:export')")
    @Log(title = "规则详情", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(ActSuppliesRoleDetail actSuppliesRoleDetail)
    {
        List<ActSuppliesRoleDetail> list = actSuppliesRoleDetailService.selectActSuppliesRoleDetailList(actSuppliesRoleDetail);
        ExcelUtil<ActSuppliesRoleDetail> util = new ExcelUtil<ActSuppliesRoleDetail>(ActSuppliesRoleDetail.class);
        return util.exportExcel(list, "规则详情数据");
    }

    /**
     * 获取规则详情详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return AjaxResult.success(actSuppliesRoleDetailService.selectActSuppliesRoleDetailById(id));
    }

    /**
     * 新增规则详情
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:add')")
    @Log(title = "规则详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ActSuppliesRoleDetail actSuppliesRoleDetail)
    {
        return toAjax(actSuppliesRoleDetailService.insertActSuppliesRoleDetail(actSuppliesRoleDetail));
    }

    /**
     * 修改规则详情
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:edit')")
    @Log(title = "规则详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ActSuppliesRoleDetail actSuppliesRoleDetail)
    {
        return toAjax(actSuppliesRoleDetailService.updateActSuppliesRoleDetail(actSuppliesRoleDetail));
    }

    /**
     * 删除规则详情
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:remove')")
    @Log(title = "规则详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(actSuppliesRoleDetailService.deleteActSuppliesRoleDetailByIds(ids));
    }

    /**
     * 启用物料总分类管理
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:enable')")
    @GetMapping("/enable/{id}")
    public AjaxResult setEnable(@PathVariable("id") Long id)
    {
        System.out.println("开始处理【启用物料总分类管理】的请求，参数：{}"+ id);
        actSuppliesRoleDetailService.setEnable(id);
        return AjaxResult.success();
    }

    /**
     * 禁用物料总分类管理
     */
    @PreAuthorize("@ss.hasPermi('system:suppliesroledetail:Disable')")
    @GetMapping("/disable/{id}")
    public AjaxResult setDisable(@PathVariable("id") Long id)
    {
        System.out.println("开始处理【禁用物料总分类管理】的请求，参数：{}"+ id);
        actSuppliesRoleDetailService.setDisable(id);
        return AjaxResult.success();

    }
}
